/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
var aLangKeys = new Object();
var lang;
var back = document.getElementsByClassName('right_col')[0];
let menu_bread = document.getElementById('menu_bread');
var log = localStorage.getItem('log') || false;

var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mon_8","mon_9","mon_10","mon_11"];



var devLangKeys = new Object();
if(localStorage.getItem('devLang')){
  devLangKeys = JSON.parse(localStorage.getItem('devLang'))
}

if(localStorage.getItem('right_col')){
back.classList.add(localStorage.getItem('right_col'));
} else{
back.classList.add(`img_0`)
}
/**
 * It takes a JSON object as a parameter, then loops through all the elements with the attribute "key"
 * and replaces the innerHTML with the value of the key attribute in the JSON object
 * @param params - The object that contains the language keys and their values.
 */
 function _Translate(params) {
  console.log('init translatejs');
  aLangKeys = params
  // console.log(params)
      if(localStorage.getItem('lang')){
          lang = localStorage.getItem('lang')
          // console.log(localStorage.getItem('lang'));
        }
  let lang_list = document.getElementById('lang_list');
  // let lang_list_2 = document.getElementById('lang_list_2');
  // lang_list_2.innerHTML="";
  lang_list.innerHTML="";
  let zusatzlang = params.zusatzlang;
  let primarylang = params.lang;
  let li_pl = document.createElement('li');
  let div_pl = document.createElement('div');
  div_pl.classList.add('col-md-3', 'col-sm-12', 'form-group')
  div_pl.innerHTML = `<a href="#" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${primarylang.split(' ')[0]}.png"> ${primarylang.split(' ')[1]}</a>`
  li_pl.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
  li_pl.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${primarylang.split(' ')[0]}.png">${primarylang.split(' ')[1]}</a>`
  lang_list.prepend(li_pl)
  // lang_list_2.prepend(div_pl)
  zusatzlang.forEach(langs => {
  let div = document.createElement('div');
  div.classList.add('col-md-3', 'col-sm-12', 'form-group')
  div.innerHTML = `<a href="#" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${langs.split(' ')[0]}.png"> ${langs.split(' ')[1]}</a>`
  let li = document.createElement('li');
  li.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
  li.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${langs.split(' ')[0]}.png">${langs.split(' ')[1]}</a>`
  lang_list.append(li)
  // lang_list_2.append(div)
  });
  for(const key3 in document.querySelectorAll('[key-place]')){
    const element3 = document.querySelectorAll('[key-place]')[key3];
      if(element3.tagName){
       let ele = element3.getAttribute('key-place')
       element3.setAttribute('placeholder',params[lang][ele])
       if(element3.getAttribute('placeholder')=="undefined"){
        devLangKeys[element3.getAttribute('key-place')]=element3.getAttribute('key-place')
       } else{
        devLangKeys[element3.getAttribute('key-place')]=element3.getAttribute('placeholder')
       }
      localStorage.setItem('devLang',JSON.stringify(devLangKeys))
      }

  }
  for(const key2 in document.querySelectorAll('[key-title]')){
    const element2 = document.querySelectorAll('[key-title]')[key2];
      if(element2.tagName){
       let ele = element2.getAttribute('key-title')
       element2.setAttribute('title',params[lang][ele])
       if(element2.getAttribute('title')=="undefined"){
        devLangKeys[element2.getAttribute('key-title')]=element2.getAttribute('key-title')
       } else{
        devLangKeys[element2.getAttribute('key-title')]=element2.getAttribute('title')
       }
      localStorage.setItem('devLang',JSON.stringify(devLangKeys))
      }
  }
  for(const key4 in document.querySelectorAll('[key-readme]')){
    const readmeElement = document.querySelectorAll('[key-readme]')[key4];
    // console.log('ReadmeElement:',readmeElement);
    if(readmeElement.tagName){
      readmeElement.classList.add('readme','mdi','mdi-help-circle-outline')
      let varRead = readmeElement.getAttribute('key-readme');
      CreateReadMeMod(varRead);
      readmeElement.setAttribute('onclick',`OpenReadMe('${varRead}')`) //Z 634
    }
  }
  for (const key in document.querySelectorAll('[key]')) {
    const element = document.querySelectorAll('[key]')[key];
    if(element.innerHTML){
    element.innerHTML = params[lang][element.getAttribute("key")];
    if(element.innerHTML=="undefined"){
      devLangKeys[element.getAttribute('key')]=element.getAttribute('key')
    } else{
      devLangKeys[element.getAttribute('key')]=element.innerHTML
    }
    localStorage.setItem('devLang',JSON.stringify(devLangKeys))
    }
  }
  $("#sprachwahl").attr("src", `images/${lang}.png`);
}

/**
 * It sets the language to the local storage and then fetches the json file and translates the page.
 * @param lang - The language you want to translate to.
 */
function langSelected(lang) {
  let httplang = new XMLHttpRequest();
  let result = lang.substring(0, 2);
  var url = "/production/setlanguagefile.tcls?systemsprache="+result;
  localStorage.setItem('lang',result)
  fetch("/production/localisation/lang.json", {
    mode: "no-cors",
  }) // disable CORS because path does not contain http(s)
    .then((res) => res.json())
    .then((data) => (_Translate(data)));

  httplang.open("GET", url, true);
  httplang.send();

}

/**
 * It fetches the JSON file, then calls the _Translate function with the JSON file as an argument.
 */
function translatejs() {
  try {
    fetch("/production/localisation/lang.json?v=1", {
      mode: "no-cors",
    }) // disable CORS because path does not contain http(s)
      .then((res) => res.json())
      .then((data) => (_Translate(data)));
  } catch (error) {
    console.log(error);
  }


}

$(document).ready(function () {
  translatejs();
  // lang = localStorage.getItem('lang')||null;
  // // console.log(localStorage);
  // if (lang == null) {
  //   if (
  //     navigator.language.includes('de')||
  //     navigator.language.includes('en')||
  //     navigator.language.includes('es')||
  //     navigator.language.includes('pt')
  //   ) {
  //     lang = navigator.language.split('-')[0];
  //     localStorage.setItem('lang',lang)
  //     $("#sprachwahl").attr("src", `images/${lang}.png`);
  //     console.log(`Sprache auf "${lang}" gesetzt`);
  //   } else {
  //     lang = "en";
  //     localStorage.setItem('lang',lang)
  //     $("#sprachwahl").attr("src", `images/${lang}.png`);

  //     console.log(`Browsersprache konnte nicht ermittelt werden und wurde auf ${lang} gesetzt`);
  //   }
  // } else {
  //   console.log("Sprache: " + lang);
  //   $("#sprachwahl").attr("src", `images/${lang}.png`);
  //   fetch("/production/localisation/lang.json", {
  //     mode: "no-cors",
  //   }) // disable CORS because path does not contain http(s)
  //     .then((res) => res.json())
  //     .then((data) => (_Translate(data)));
  // }
  localstart();
});

// Fullscreen
/* A JavaScript function that is executed when the user clicks on a language button. */
$(document).ready(function () {
  $(".fullscreen_button").on("click", function () {
    (document.fullScreenElement && null !== document.fullScreenElement) ||
    (!document.mozFullScreen && !document.webkitIsFullScreen)
      ? document.documentElement.requestFullScreen
        ? document.documentElement.requestFullScreen()
        : document.documentElement.mozRequestFullScreen
        ? document.documentElement.mozRequestFullScreen()
        : document.documentElement.webkitRequestFullScreen &&
          document.documentElement.webkitRequestFullScreen(
            Element.ALLOW_KEYBOARD_INPUT
          )
      : document.cancelFullScreen
      ? document.cancelFullScreen()
      : document.mozCancelFullScreen
      ? document.mozCancelFullScreen()
      : document.webkitCancelFullScreen && document.webkitCancelFullScreen();
  });
});

/**
 * The function starts a countdown and then reboots the Velobox
 */
function reboot() {
  var url = "/production/reboot.tcls";

  // btn1 ist das X zum schließen des Fensters
  //var btn1 = document.getElementById("btn1");
  //btn1.setAttribute("disabled", "true");
  localStorage.clear()

  var btn2 = document.getElementById("btn2");
  btn2.setAttribute("disabled", "true");

  var btn3 = document.getElementById("btn3");
  btn3.setAttribute("disabled", "true");

  countdown();

  httpreboot.open("GET", url, true);
  httpreboot.send();
} // reboot()

/**
 * It counts down from 60 seconds and reloads the page when it reaches 0
 */
function countdown() {
  var seconds = 50;
  var progress = document.getElementById('progress_restart')
  function tick() {
    // var counter = document.getElementById("counter");
    seconds--;
    // counter.innerHTML =
    //   '<span class="tr" key="global_einsatzbereit"><!--Die Velobox ist wieder einsatzbereit in nur--></span> <b>0:' +
    //   (seconds < 10 ? "0" : "") +
    //   String(seconds) +
    //   '</b> <span class="tr" key="global_minuten"><!--Minuten--></span>';
      progress.value +=1
    if (seconds > 0) {
      setTimeout(tick, 1000);
    } else {
      location.pathname = "/"
    }
  }
   translatejs();
  tick();
}
/**
 * It takes an array of strings and creates a breadcrumb navigation bar
 * @param {Arraya<string>}params - an array of strings that will be used to create the breadcrumb.
 */
function BreadCrumb(params) {
    var path = $('.meinpfad')[0];
    path.innerHTML = "";
    var ihome = document.createElement('i');
    ihome.classList.add('mdi','mdi-sitemap')
    var spanhome = document.createElement('span');
    // spanhome.classList.add('tr')
    spanhome.setAttribute('key','mainmenu_home');
    spanhome.setAttribute('onclick',`LinkTo('dashboard.tcls')`)
    path.append(ihome);
    path.append(spanhome);
    params.forEach(element => {
      var i = document.createElement('i');
      i.classList.add('mdi','mdi-menu-right');
      path.append(i);
      var s = document.createElement('span');
      // s.classList.add('tr');
      s.setAttribute('key',`bread_${element}`)
      s.setAttribute('onclick',`LinkTo('${element}.tcls')`)
      s.setAttribute('style','cursor: pointer')
      s.innerHTML = element;
      path.append(s);
      // if(element !='dashboard'){
        let li = document.createElement('li');
        let a = document.createElement('a');
        a.classList.add('font-12');
        a.setAttribute('key',`bread_${element}`);
        a.setAttribute('href',`/production/${element}.tcls`)
        a.id = element.replaceAll(' ','')
        a.innerHTML = element
        //if(location.pathname == "/production/dashboard.tcls"){
        // li.classList.add('hidden')
        //}
        if(element==='client'){
          a.removeAttribute('key');
          a.innerHTML = localStorage.getItem('client_name')
          s.removeAttribute('key');
          s.innerHTML = localStorage.getItem('client_name')
        }
        menu_bread.append(li)
        li.append(a)
      // }

    });
    //  translatejs();
}
/**
 * It removes the local storage items 'ReadFirstStart' and 'ReadFirstSatteldruckanalyse'
 */
function HelpReset() {
  localStorage.removeItem("ReadFirstStart");
  localStorage.removeItem("ReadFirstSatteldruckanalyse");
}

/**
 * It sends a request to the server to get the handbook file for the selected language
 * @param sprache - The language of the handbook.
 */
 function setHandbuchfile(sprache) {

  var url = "/production/korrekturhandbuch.tcls?sprache=" + sprache;

  httpSetconfig.open("GET", url, true);
  httpSetconfig.send();

}

/**
 * The function takes a parameter, which is the name of the page you want to link to, and then it
 * changes the location of the current page to the page you want to link to
 * @param params - The name of the parameter you want to pass to the function.
 */
function LinkTo(params) {
  location.href = `/production/${params}`
}

/**
* It checks if the user has already seen the first start modal and if not, it shows it
*/
function localstart() {

  if (localStorage.getItem("ReadFirstStart") === null) {
      console.log("Init FirstStart");
      localStorage.setItem("ReadFirstStart", false);
  }

  if (localStorage.getItem("viewmode") === null) {
      console.log("Init ViewMode");
      localStorage.setItem("viewmode", "basic");
  }

  if (localStorage.getItem("ReadFirstSatteldruckanalyse") === null) {
      console.log("Init FirstSatteldruckanalyse");
      localStorage.setItem("ReadFirstSatteldruckanalyse", false);
  }

  if (localStorage.getItem("ReadFirstSatteldruckanalyse") === "false" && document.getElementById("firstsatteldruckanalyse")) {
      $("#firstsatteldruckanalyse").modal("show");
  }

  if (localStorage.getItem("ReadFirstStart") === "false") {
      $("#firststart").modal("show");
  } else {
      console.log(
          "FirstStart deactivated",
          localStorage.getItem("ReadFirstStart")
      );
  }
}

if(location.pathname == "/production/dashboard.tcls"){
  BreadCrumb(['dashboard']);
}
if(location.pathname == "/production/clients.tcls"){
  BreadCrumb(['dashboard','clients']);
}
if(location.pathname == "/production/session.tcls"){
  BreadCrumb(['dashboard','clients','session']);
}
if(location.pathname == "/production/client.tcls"){
  BreadCrumb(['dashboard','clients','client'])
}
if(location.pathname == "/production/new_satteldruckanalyse.tcls"){
  BreadCrumb(['dashboard','clients','client','new_satteldruckanalyse']);
}
if(location.pathname == "/production/protokoll.tcls"){
  BreadCrumb(['dashboard','clients','client','protokoll'])
}
if(location.pathname == "/production/handbuch.tcls"){
  BreadCrumb(['dashboard','handbuch'])
}
if(location.pathname == "/production/system.tcls"){
  BreadCrumb(['dashboard','system'])
}
if(location.pathname == "/production/sitzknochenvermessung.tcls"){
  BreadCrumb(['dashboard','sitzknochenvermessung'])
}
if(location.pathname == "/production/wlanconfig.tcls"){
  BreadCrumb(['dashboard','wlanconfig'])
}
if(location.pathname == "/production/changelog.tcls"){
  BreadCrumb(['dashboard','changelog'])
}

var checkbox = document.getElementById('basic');
var checkbox_view = document.getElementById('switch-1')
var checkbox_mask1 = document.getElementById('mask1')
var checkbox_mask2 = document.getElementById('mask2')
var checkbox_set_comp = document.getElementById('set_comp')
var checkbox_maskedit = document.getElementById('maskedit');

function chk_wifi() {
//ETH-CONN
//headermenu_verbunden
//headermenu_nicht_verbunden
const btn_eth = document.getElementById('eth');
const span_eth = document.getElementById('eth_con');

try {
  if(btn_eth.dataset.inet != ""){
    span_eth.setAttribute('style','color: var(--primary);')
  } else {
    btn_eth.classList.remove('mdi-lan-connect')
    btn_eth.classList.add('mdi-lan-disconnect')
    btn_eth.setAttribute('disabled','')
    span_eth.setAttribute('style','color: var(--red);')
  }
} catch (error) {
  // console.log(error);
}


//WIFI-CONN
//mdi-wifi-off
const btn_wifi = document.getElementById('wifi')
const span_wifi = document.getElementById('wifi_con')
const li_id = document.getElementById('wifi_id')
const li_id_hr = document.getElementById('wifi_id_hr')

try {
  if(btn_wifi.dataset.inet != ""){
    span_wifi.setAttribute('style','color: var(--primary);')
  } else {
    btn_wifi.classList.remove('mdi-wifi')
    btn_wifi.classList.add('mdi-wifi-off')
    span_wifi.setAttribute('style','color: var(--red);')
    span_wifi.setAttribute('key','con_disconekt')
    li_id.classList.add('hidden')
    li_id_hr.classList.add('hidden')
    translatejs()
  }
} catch (error) {
  // console.log(error);
}
}

$(document).ready(function () {
  chk_wifi();
  ToggleViewMode(localStorage.getItem("viewmode"));
  if(localStorage.getItem('viewmode')==='basic'){
    checkbox_view.removeAttribute('checked');
    // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
    ToggleViewMode('basic');
  } else{
    try {
    checkbox_view.setAttribute('checked','')
    // document.getElementById("basic").nextSibling.classList.add('custom_switch')
    ToggleViewMode('advanced');
  } catch (error) {
        // console.log(error);
    }
  }
  if(location.pathname == "/production/new_satteldruckanalyse.tcls"){
    checkbox_mask1.removeAttribute('checked')
    checkbox_mask2.removeAttribute('checked')
    checkbox_maskedit.removeAttribute('checked')
  }
});



checkbox_view.addEventListener('change', function() {
if (this.checked) {
  console.log("basic is checked..");
  // document.getElementById("basic").nextSibling.classList.add('custom_switch')
  ToggleViewMode('advanced');
} else {
  console.log("basic is not checked..");
  // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
  ToggleViewMode('basic');
}
});


try {
  checkbox_mask1.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("mask1").nextSibling.classList.add('custom_switch')
      showMask(this.dataset.num)
    } else {
      document.getElementById("mask1").nextSibling.classList.remove('custom_switch')
      hideMask(this.dataset.num)
    }
    });
} catch (error) {
  // console.log(error);
}

try {
  checkbox_mask2.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("mask2").nextSibling.classList.add('custom_switch')
      showMask(this.dataset.num)
    } else {
      document.getElementById("mask2").nextSibling.classList.remove('custom_switch')
      hideMask(this.dataset.num)
    }
});
} catch (error) {
  // console.log(error);
}

try {
  checkbox_maskedit.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("maskedit").nextSibling.classList.add('custom_switch')
      hide_mask()
    } else {
      document.getElementById("maskedit").nextSibling.classList.remove('custom_switch')
      hide_mask()
    }
});
} catch (error) {
  
}

try {
  checkbox_set_comp.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("set_comp").nextSibling.classList.add('custom_switch')
      set_comp("on")
    } else {
      document.getElementById("set_comp").nextSibling.classList.remove('custom_switch')
      set_comp("off")
    }
    });
} catch (error) {
  // console.log(error);
}

var men = document.getElementById('menu_toggle');

men.addEventListener('click',()=>{
let m_men = document.getElementsByClassName('men');

  if(document.getElementsByTagName('body')[0].classList.contains('nav-md')){
    for (const iterator of m_men) {
      iterator.classList.add('hide')
    }
  } else {
    for (const iterator of m_men) {
      iterator.classList.remove('hide')
    }
  }
})

function gettrans(params) {
  lang = localStorage.getItem('lang')
  console.log(params,lang);
  translatejs()
  console.log(aLangKeys);
  try {
  return aLangKeys[lang][params]
  } catch (error) {
    console.log(error);
  }
}

function abso() {
ch = $(window).height();
cw = $(window).width()/1.25;
  $('#foo').css({
      position: 'fixed',
      background: 'white !important',
      zIndex: 1000,
      width: $(window).width(),
      height: $(window).height(),
      top: 0,
      right: '10%',
      bottom: 0,
      left: '10%'
  });
}
try {
let side_smartcube = document.getElementById('sitzknochen-menu');
if(localStorage.getItem('hocker')=="on"){
  console.log('SmartCube found');
  side_smartcube.setAttribute('href','/production/sitzknochenvermessung.tcls')
}else{
  console.log('SmartCube not found');
  side_smartcube.setAttribute('href','/production/system.tcls')
}
} catch (error) {
  
}


let clock_dash = setInterval(function () {
  let c = document.getElementById('clock');
  let time = new Date();
  let h = time.getHours() < 10 ? '0' + time.getHours() : time.getHours();
  let m = time.getMinutes() < 10 ? '0' + time.getMinutes() : time.getMinutes(); 
  let s = time.getSeconds() < 10 ? '0' + time.getSeconds() : time.getSeconds();
  let time_str = `${aLangKeys[lang][week[time.getDay()]]} ${time.getDate()} ${aLangKeys[lang][month[time.getMonth()]]} ${h}:${m}:${s}`;
  c.innerHTML = time_str;
 }, 1000);
// $(window).resize(function() {
//   abso();
// });

/**
 * It creates a new element with the given parameters and appends it to the given element
 * 
 * @function
 * @name newElement
 * @kind function
 * @param {Object<JSON>} jsn - JSON object
 * @param {String} jsn.element    - HTML element name
 * @param {String} jsn.id    - ID of the element
 * @param {Array<String>} jsn.cls - classes of the element
 * @param {Array<Array<String>>} jsn.attr - Attriburtes of the HTML element
 * @param {HTMLElement} DOM_Element - the complete element
 * @returns {HTMLElement} 
 */
function newElement(jsn, DOM_Element) {
  let e = document.createElement(jsn.element)
  if(jsn.cls){
      jsn.cls.forEach(element => {
          e.classList.add(element)            
      });
  }
  if(jsn.id){
      e.id = jsn.id
  }
  if(jsn.attr){
      jsn.attr.forEach(element=>{
          e.setAttribute(element[0],element[1])
      });
  }
  if(log){
    console.log('newElement',e);
  }
  DOM_Element.append(e)
  return e;
}

// MODAL README
function CreateReadMeMod(params) {
  let append;
  if(document.getElementById('ModalHolder')){
    append = document.getElementById('ModalHolder');
  } else {
    append = newElement({element:'div',id:'ModalHolder'},document.getElementsByTagName('body')[0]);
  }

  let ModalDiv  =  newElement({element:'div',id:`mod_${params}`,attr:[['uk-modal','']]},append);
  let ModalBody =  newElement({element:'div',cls:['uk-modal-dialog','uk-modal-body']},ModalDiv);
  let ModalBtnX =  newElement({element:'button',cls:['uk-modal-close-default'],attr:[['type','button'],['uk-close','']]},ModalBody);
  // let ModalH2   =  newElement({element:'h2',cls:['uk-modal-title']},ModalBody);
  // ModalH2.innerHTML= aLangKeys[lang][params]
  let ModalReadmeText1 = newElement({element:'p'},ModalBody);

  fetch(`/production/manuals/${lang}/${params}.html?v=1`, {
    mode: "no-cors",
  }) // disable CORS because path does not contain http(s)
    .then((res) => res.text())
    .then((data) => (ModalReadmeText1.innerHTML=data));

  // ModalReadmeText1.innerHTML = aLangKeys[lang][`${params}__HTML`]


}

// OpenReadMe
function OpenReadMe(params) {
  UIkit.modal(`#mod_${params}`).show();
}

if(location.pathname == '/production/sitzknochenvermessung.tcls'){
  var menueintrag = document.getElementById('sitzknochenvermessung');
  menueintrag.classList.add('hidden');
}

function openWindow() {
  window.open(`${location.origin}`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
  this.close()
}
